/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Master of Desaster:
 *      Manuel Meier
 *   Co-authors:
 *      Cyrill Burgener
 *      Tomer Gidron
 *
 */

/**
    @file Hover.h
    @brief Gametype. For more information see .cc file
    @ingroup Hover
*/

#ifndef _Hover_H__
#define _Hover_H__

#include "HoverPrereqs.h"
#include "HoverShip.h"

#include <vector>

#include "gametypes/Gametype.h"
#include "HoverOrigin.h"
#include "pickup/PickupSpawner.h"

namespace orxonox
{
    class _HoverExport Hover : public Gametype
    {
       public:
            Hover(Context* context);

            virtual void tick(float dt) override;

            void setOrigin(HoverOrigin* origin)
                { this->origin_ = origin; }

            void start();
            void createFlags();
            void levelUp();
            void endLevel();
            void costLife();

            inline int getNumberOfFlags() const
                { return this->numberOfFlags_; }

            virtual Vector3 get3dCoordinates(int x, int y, float heightOffset);

            inline int getTotFlags() const
                { return this->totFlags; }

            inline int getLives() const
                { return this->lives; }

            inline int getLevel() const
                { return this->level; }

            bool bLevelUpgradeHUD;

        private:

            WeakPtr<HoverOrigin> origin_;
            std::vector<HoverFlag*> flags_;
            int numberOfFlags_;
            bool firstTick_;
            int level;
            int lives;
            int flagsTaken;

            int cellSize;
            int cellHeight;
            int numCells;

            int totFlags;

            std::vector<PickupSpawner*> pickupSpawners_;

            void toggleShowLevel(){bLevelUpgradeHUD = !bLevelUpgradeHUD;}

            Timer showLevelTimer;
    };
}

#endif /* _Hover_H__ */
